@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,7 +69,7 @@ import com.openexchange.spamhandler.defaultspamhandler.MailServiceSupplier;
 public final class DefaultSpamHandlerActivator extends DeferredActivator {
 
     private static final org.apache.commons.logging.Log LOG =
-        org.apache.commons.logging.LogFactory.getLog(DefaultSpamHandlerActivator.class);
+        com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(DefaultSpamHandlerActivator.class));
 
     private final Dictionary<String, String> dictionary;
 
